##  Guidelines and Best Practices
  * Model platforms only if it makes sense to your organization - e.g., model digital platforms if this is something typically understood by your C-Suite. Usually, organizations speak about, e.g., digital platforms as part of their high-level strategy.
  * Less is more - reduce to a few platforms (without hierarchy) to simplify communication.
  * Business applications are a key part of each digital platform. Typically, each organization would have at least 2-3 platforms that drive change from the CIO level and improve a number of strategic business capabilities. The following example shows a view in the application landscape report.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27564f257a441014975788139c741976_LowRes.png)
  * In addition, as shown in the matrix report below, platforms will often be defined in a way that supports specific capabilities of the business, e.g., ERP platform / digital process platforms supporting manufacturing / finance capabilities.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a1fc27a4410148a39c319c0bab5b2_LowRes.png)
  * There's also the important notion of platform ownership, i.e., who is responsible for ensuring that the platforms are seen as the clear reference for a harmonized global implementation of ERP systems?
  * A platform can also be a (technical) grouping of IT components and is described as a clear reference when considering the underlying components of applications later on. You can use, e.g., the landscape report to see which IT components belong to your platform - in this example, the Windows Client platform.
  * A platform can express strategic IT standards and track the adoption (e.g., how many applications rely on the Windows Client platform). You can reuse it to show which organizational entities use the standard and create a follow-up platform that possibly includes more features to be rolled out to all regions, etc.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27568c1e7a441014a17fdb96237b0b4b_LowRes.png)
